@@ -19,7 +19,7 @@ Moose::Exporter->setup_import_methods(
     #with_meta => ['operation'],
 );
 
-our $VERSION = version->new('0.4.0');
+our $VERSION = version->new('0.4.1');
 
 Moose::Util::meta_attribute_alias('Getopt::Alt::Option');
 
@@ -232,12 +232,20 @@ sub process {
         }
 
         $DB::single = 1;
-        $value =
-              $self->nullable      &&   !        $arg_data                                  ? undef
-            : $self->type eq 'Int' && $arg_data =~ /^ -? \d+$/xms                           ? $arg_data
-            : $self->type eq 'Num' && $arg_data =~ /^ -? (?: \d* (?: [.]\d+ )? | \d+ )$/xms ? $arg_data
-            : $self->type eq 'Str'                                                          ? $arg_data
-            :                                                                                 confess "Unknown type '".$self->type."'\n";
+        $value = $arg_data;
+
+        if ( $self->nullable && ( ! defined $arg_data || $arg_data eq '' ) ) {
+            $value = undef;
+        }
+        elsif ( $self->type eq 'Int' ) {
+            confess "$name '$arg_data' is not an integer!" if $arg_data !~ /^ -? \d+ $/xms;
+        }
+        elsif ( $self->type eq 'Num' ) {
+            confess "$name '$arg_data' is not a number!" if $arg_data !~ /^ -? (?: \d* (?: [.]\d+ )? | \d+ ) $/xms;
+        }
+        elsif ( $self->type ne 'Str' ) {
+            confess "Unknown type '".$self->type."'\n";
+        }
 
         if ($self->values && !grep { $value eq $_ } @{ $self->values }) {
             die [ Getopt::Alt::Exception->new(
@@ -285,7 +293,7 @@ Getopt::Alt::Option - Sets up a particular command line option
 
 =head1 VERSION
 
-This documentation refers to Getopt::Alt::Option version 0.4.0.
+This documentation refers to Getopt::Alt::Option version 0.4.1.
 
 =head1 SYNOPSIS
 
